aboutsummaryrefslogtreecommitdiff
path: root/mesonbuild/build.py
diff options
context:
space:
mode:
Diffstat (limited to 'mesonbuild/build.py')
-rw-r--r--mesonbuild/build.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/mesonbuild/build.py b/mesonbuild/build.py
index 5408b21..2f325ae 100644
--- a/mesonbuild/build.py
+++ b/mesonbuild/build.py
@@ -740,7 +740,7 @@ class BuildTarget(Target):
self.rpath_dirs_to_remove: T.Set[bytes] = set()
self.process_sourcelist(sources)
# Objects can be:
# 1. Pre-existing objects provided by the user with the `objects:` kwarg
# 2. Compiled objects created by and extracted from another target
self.process_objectlist(objects)
self.process_kwargs(kwargs)
@@ -811,8 +811,8 @@ class BuildTarget(Target):
"""Split sources into generated and static sources.
Sources can be:
- 1. Pre-existing source files in the source tree (static)
- 2. Pre-existing sources generated by configure_file in the build tree.
+ 1. Preexisting source files in the source tree (static)
+ 2. Preexisting sources generated by configure_file in the build tree.
(static as they are only regenerated if meson itself is regenerated)
3. Sources files generated by another target or a Generator (generated)
"""
@@ -884,7 +884,7 @@ class BuildTarget(Target):
missing_languages: T.List[str] = []
if not any([self.sources, self.generated, self.objects, self.structured_sources]):
return missing_languages
- # Pre-existing sources
+ # Preexisting sources
sources: T.List['FileOrString'] = list(self.sources)
generated = self.generated.copy()
@@ -1654,7 +1654,7 @@ You probably should put it in link_with instead.''')
'\n '
f'If shared_module() was used for {link_target.name} because it has references to undefined symbols,'
'\n '
- 'use shared_libary() with `override_options: [\'b_lundef=false\']` instead.')
+ 'use shared_library() with `override_options: [\'b_lundef=false\']` instead.')
link_target.force_soname = True
class Generator(HoldableObject):
@@ -740,7 +740,7 @@ class BuildTarget(Target):
self.process_sourcelist(sources)
# Objects can be:
- # 1. Pre-existing objects provided by the user with the `objects:` kwarg
+ # 1. Preexisting objects provided by the user with the `objects:` kwarg
# 2. Compiled objects created by and extracted from another target
self.process_objectlist(objects)